@@ -1,3 +1,6 @@
+#ifndef _KVI_SHORTCUT_CLASSFILE_H_
+	#error "Do not include kvi_shortcuts.h config file directly: include KviShortcut.h class header instead."
+#endif
 #ifndef _KVI_SHORTCUTS_H_
 #define _KVI_SHORTCUTS_H_
 //=============================================================================
@@ -5,7 +8,7 @@
 //   File : kvi_shortcuts.h
 //   Creation date : Fri Dec 11 2009 16:24:46 CEST by Elvio Basello
 //
-//   This file is part of the KVirc irc client distribution
+//   This file is part of the KVIrc irc client distribution
 //   Copyright (C) 2009 Elvio Basello (hell at hellvis69 dot netsons dot org)
 //
 //   This program is FREE software. You can redistribute it and/or
@@ -43,7 +46,9 @@
 * \def KVI_SHORTCUTS_OPTIONS Open "Options" dialog
 * \def KVI_SHORTCUTS_SERVERS Open "Servers" dialog
 * \def KVI_SHORTCUTS_THEME Open "Theme Options" dialog
-* \def KVI_SHORTCUTS_USERS Open "Registered users" dialog
+* \def KVI_SHORTCUTS_USERS Open "Registered Users" dialog
+* \def KVI_SHORTCUTS_MANAGE_THEMES Open "Manage Theme" dialog
+* \def KVI_SHORTCUTS_MANAGE_ADDONS Open "Manage Theme" dialog
 *
 * \def KVI_SHORTCUTS_INPUT_ALT Alt key
 * \def KVI_SHORTCUTS_INPUT_ALT_2 Meta key
@@ -72,7 +77,6 @@
 * \def KVI_SHORTCUTS_INPUT_NEXT_WORD Move to the end of the next word
 * \def KVI_SHORTCUTS_INPUT_NEXT_WORD_SELECT Select up to the end of the next word
 * \def KVI_SHORTCUTS_INPUT_PASTE Paste the clipboard contents (same as middle mouse click)
-* \def KVI_SHORTCUTS_INPUT_PASTE_2 Paste the clipboard contents (same as middle mouse click)
 * \def KVI_SHORTCUTS_INPUT_PLAINTEXT Insert the 'non-crypt' (plain text) KVIrc control character used to disable encryption of the current text line
 * \def KVI_SHORTCUTS_INPUT_PREV_CHAR Move the cursor to the left
 * \def KVI_SHORTCUTS_INPUT_PREV_CHAR_SELECT Move the selection to the left
@@ -81,13 +85,13 @@
 * \def KVI_SHORTCUTS_INPUT_REDO Redo last action
 * \def KVI_SHORTCUTS_INPUT_RESET Insert Reset control character
 * \def KVI_SHORTCUTS_INPUT_RETURN Return key
-* \def KVI_SHORTCUTS_INPUT_RETURN_2 Shift + Return key
-* \def KVI_SHORTCUTS_INPUT_RETURN_3 Enter key
-* \def KVI_SHORTCUTS_INPUT_RETURN_4 Shift + Enter key
+* \def KVI_SHORTCUTS_INPUT_RETURN_2 Enter key
 * \def KVI_SHORTCUTS_INPUT_REVERSE Insert the 'reverse' mIRC text control character
 * \def KVI_SHORTCUTS_INPUT_SELECT_ALL Select all
 * \def KVI_SHORTCUTS_INPUT_SEND_PLAIN Send message as plain text, ignoring / commands
 * \def KVI_SHORTCUTS_INPUT_SEND_PLAIN_2 Send message as plain text, ignoring / commands
+* \def KVI_SHORTCUTS_INPUT_SEND_KVS Send message as kvs
+* \def KVI_SHORTCUTS_INPUT_SEND_KVS_2 Send message as kvs
 * \def KVI_SHORTCUTS_INPUT_UNDERLINE Insert the 'underline' mIRC text control character
 * \def KVI_SHORTCUTS_INPUT_UNDO Undo last action
 * \def KVI_SHORTCUTS_INPUT_DUMMY Dummy combo
@@ -114,29 +118,33 @@
 * \def KVI_SHORTCUTS_WIN_PREV_HIGHLIGHT Previous highlighted window
 * \def KVI_SHORTCUTS_WIN_PREV_LINE Scroll the output window up one line
 * \def KVI_SHORTCUTS_WIN_PREV_PAGE Scroll the output window up one page
+* \def KVI_SHORTCUTS_WIN_SCROLL_TO_LAST_READ_LINE Scroll to the last read line
 * \def KVI_SHORTCUTS_WIN_SEARCH Open "Find Text" dialog
+* \def KVI_SHORTCUTS_WIN_ZOOM_IN Increase font size
+* \def KVI_SHORTCUTS_WIN_ZOOM_OUT Decrease font size
 */
 
 // Please keep this list ordered by shortcut key and not by name :)
-#define KVI_SHORTCUTS_HELP "F1"
-#define KVI_SHORTCUTS_INPUT_SELECT_ALL "Ctrl+A"
-#define KVI_SHORTCUTS_INPUT_BOLD "Ctrl+B"
-#define KVI_SHORTCUTS_INPUT_COPY "Ctrl+C"
-#define KVI_SHORTCUTS_WIN_SEARCH "Ctrl+F"
-#define KVI_SHORTCUTS_INPUT_ICON "Ctrl+I"
+#define KVI_SHORTCUTS_HELP QKeySequence::HelpContents				// F1
+#define KVI_SHORTCUTS_INPUT_SELECT_ALL QKeySequence::SelectAll			// Ctrl+A
+#define KVI_SHORTCUTS_INPUT_BOLD QKeySequence::Bold				// Ctrl+B
+#define KVI_SHORTCUTS_INPUT_COPY QKeySequence::Copy				// Ctrl+C
+#define KVI_SHORTCUTS_WIN_SEARCH QKeySequence::Find				// Ctrl+F
+#define KVI_SHORTCUTS_INPUT_ICON QKeySequence::Italic				// Ctrl+I <= yes we know this should be "italic"
 #define KVI_SHORTCUTS_JOIN "Ctrl+J"
 #define KVI_SHORTCUTS_INPUT_COLOR "Ctrl+K"
-#define KVI_SHORTCUTS_CONTEXT "Ctrl+N"
+#define KVI_SHORTCUTS_WIN_SCROLL_TO_LAST_READ_LINE "Ctrl+L"
+#define KVI_SHORTCUTS_CONTEXT QKeySequence::New					// Ctrl+N
 #define KVI_SHORTCUTS_INPUT_RESET "Ctrl+O"
 #define KVI_SHORTCUTS_INPUT_PLAINTEXT "Ctrl+P"
 #define KVI_SHORTCUTS_INPUT_REVERSE "Ctrl+R"
 #define KVI_SHORTCUTS_SERVERS "Ctrl+S"
-#define KVI_SHORTCUTS_INPUT_UNDERLINE "Ctrl+U"
-#define KVI_SHORTCUTS_INPUT_PASTE "Ctrl+V"
-//Ctrl+W: No need to implement this since it's hardcoded in Qt's MDI
-#define KVI_SHORTCUTS_INPUT_CUT "Ctrl+X"
+#define KVI_SHORTCUTS_INPUT_UNDERLINE QKeySequence::Underline			// Ctrl+U
+#define KVI_SHORTCUTS_INPUT_PASTE QKeySequence::Paste				// Ctrl+V
+//Ctrl+W: No need to implement this since it's hardcoded in Qt's MDI (it should be QKeySequence::Close)
+#define KVI_SHORTCUTS_INPUT_CUT QKeySequence::Cut				// Ctrl+X
 #define KVI_SHORTCUTS_INPUT_COMMANDLINE "Ctrl+Y"
-#define KVI_SHORTCUTS_INPUT_UNDO "Ctrl+Z"
+#define KVI_SHORTCUTS_INPUT_UNDO QKeySequence::Undo				// Ctrl+Z
 #define KVI_SHORTCUTS_AWAY "Ctrl+Shift+A"
 #define KVI_SHORTCUTS_EDITORS_TOOLBAR "Ctrl+Shift+B"
 #define KVI_SHORTCUTS_CONNECT "Ctrl+Shift+C"
@@ -144,6 +152,8 @@
 #define KVI_SHORTCUTS_EDITORS_EVENT "Ctrl+Shift+E"
 #define KVI_SHORTCUTS_IDENTITY "Ctrl+Shift+I"
 #define KVI_SHORTCUTS_EDITORS_ALIAS "Ctrl+Shift+L"
+#define KVI_SHORTCUTS_MANAGE_THEMES "Ctrl+Shift+M"
+#define KVI_SHORTCUTS_MANAGE_ADDONS "Ctrl+Shift+N"
 #define KVI_SHORTCUTS_OPTIONS "Ctrl+Shift+O"
 #define KVI_SHORTCUTS_EDITORS_POPUP "Ctrl+Shift+P"
 #define KVI_SHORTCUTS_EDITORS_ACTION "Ctrl+Shift+Q"
@@ -152,7 +162,7 @@
 #define KVI_SHORTCUTS_THEME "Ctrl+Shift+T"
 #define KVI_SHORTCUTS_USERS "Ctrl+Shift+U"
 #define KVI_SHORTCUTS_EXEC "Ctrl+Shift+X"
-#define KVI_SHORTCUTS_INPUT_REDO "Ctrl+Shift+Z"
+#define KVI_SHORTCUTS_INPUT_REDO QKeySequence::Redo				// Ctrl+Shift+Z
 #define KVI_SHORTCUTS_WIN_PREV Qt::AltModifier + Qt::Key_Up
 #define KVI_SHORTCUTS_WIN_NEXT Qt::AltModifier + Qt::Key_Down
 #define KVI_SHORTCUTS_WIN_PREV_CONTEXT Qt::AltModifier + Qt::ShiftModifier + Qt::Key_Up
@@ -161,46 +171,44 @@
 #define KVI_SHORTCUTS_WIN_NEXT_HIGHLIGHT Qt::AltModifier + Qt::Key_PageDown
 #define KVI_SHORTCUTS_WIN_MAXIMIZE Qt::ControlModifier + Qt::Key_Up
 #define KVI_SHORTCUTS_WIN_MINIMIZE Qt::ControlModifier + Qt::Key_Down
-#define KVI_SHORTCUTS_INPUT_PASTE_2 Qt::ShiftModifier + Qt::Key_Insert
-#define KVI_SHORTCUTS_WIN_PREV_PAGE Qt::Key_PageUp
-#define KVI_SHORTCUTS_WIN_NEXT_PAGE Qt::Key_PageDown
+#define KVI_SHORTCUTS_WIN_PREV_PAGE QKeySequence::MoveToPreviousPage		// Qt::Key_PageUp
+#define KVI_SHORTCUTS_WIN_NEXT_PAGE QKeySequence::MoveToNextPage		// Qt::Key_PageDown
 #define KVI_SHORTCUTS_WIN_PREV_LINE Qt::ShiftModifier + Qt::Key_PageUp
 #define KVI_SHORTCUTS_WIN_NEXT_LINE Qt::ShiftModifier + Qt::Key_PageDown
-#define KVI_SHORTCUTS_INPUT_PREV_WORD Qt::ControlModifier + Qt::Key_Left
-#define KVI_SHORTCUTS_INPUT_NEXT_WORD Qt::ControlModifier + Qt::Key_Right
-#define KVI_SHORTCUTS_INPUT_PREV_WORD_SELECT Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_Left
-#define KVI_SHORTCUTS_INPUT_NEXT_WORD_SELECT Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_Right
+#define KVI_SHORTCUTS_INPUT_PREV_WORD QKeySequence::MoveToPreviousWord		// Qt::ControlModifier + Qt::Key_Left
+#define KVI_SHORTCUTS_INPUT_NEXT_WORD QKeySequence::MoveToNextWord		// Qt::ControlModifier + Qt::Key_Right
+#define KVI_SHORTCUTS_INPUT_PREV_WORD_SELECT QKeySequence::SelectPreviousWord	// Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_Left
+#define KVI_SHORTCUTS_INPUT_NEXT_WORD_SELECT QKeySequence::SelectNextWord	// Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_Right
 //Ctrl+<digit>: Script accelerators (see OnAccelKeyPressed)
 //F2-F12, Shift+(F1-F12): Script accelerators (see OnAccelKeyPressed)
 #define KVI_SHORTCUTS_INPUT_HISTORY Qt::ControlModifier + Qt::Key_PageUp
-#define KVI_SHORTCUTS_INPUT_PREV_CHAR Qt::Key_Left
-#define KVI_SHORTCUTS_INPUT_NEXT_CHAR Qt::Key_Right
-#define KVI_SHORTCUTS_INPUT_PREV_CHAR_SELECT Qt::ShiftModifier + Qt::Key_Left
-#define KVI_SHORTCUTS_INPUT_NEXT_CHAR_SELECT Qt::ShiftModifier + Qt::Key_Right
-#define KVI_SHORTCUTS_INPUT_DELETE_WORD Qt::ControlModifier + Qt::Key_Backspace
+#define KVI_SHORTCUTS_INPUT_PREV_CHAR QKeySequence::MoveToPreviousChar		// Qt::Key_Left
+#define KVI_SHORTCUTS_INPUT_NEXT_CHAR QKeySequence::MoveToNextChar		// Qt::Key_Right
+#define KVI_SHORTCUTS_INPUT_PREV_CHAR_SELECT QKeySequence::SelectPreviousChar	// Qt::ShiftModifier + Qt::Key_Left
+#define KVI_SHORTCUTS_INPUT_NEXT_CHAR_SELECT QKeySequence::SelectNextChar	// Qt::ShiftModifier + Qt::Key_Right
+#define KVI_SHORTCUTS_INPUT_DELETE_WORD QKeySequence::DeleteStartOfWord		// Qt::ControlModifier + Qt::Key_Backspace
 #define KVI_SHORTCUTS_INPUT_MULTILINE Qt::AltModifier + Qt::Key_Return
 #define KVI_SHORTCUTS_INPUT_MULTILINE_2 Qt::AltModifier + Qt::Key_Enter
 #define KVI_SHORTCUTS_INPUT_SEND_PLAIN Qt::ControlModifier + Qt::Key_Return
 #define KVI_SHORTCUTS_INPUT_SEND_PLAIN_2 Qt::ControlModifier + Qt::Key_Enter
-#define KVI_SHORTCUTS_INPUT_HOME Qt::Key_Home
-#define KVI_SHORTCUTS_INPUT_END Qt::Key_End
-#define KVI_SHORTCUTS_INPUT_HOME_SELECT Qt::ShiftModifier + Qt::Key_Home
-#define KVI_SHORTCUTS_INPUT_END_SELECT Qt::ShiftModifier + Qt::Key_End
-#define KVI_SHORTCUTS_INPUT_HISTORY_PREV Qt::Key_Up
-#define KVI_SHORTCUTS_INPUT_HISTORY_NEXT Qt::Key_Down
+#define KVI_SHORTCUTS_INPUT_SEND_KVS Qt::ShiftModifier + Qt::Key_Return
+#define KVI_SHORTCUTS_INPUT_SEND_KVS_2 Qt::ShiftModifier + Qt::Key_Enter
+#define KVI_SHORTCUTS_INPUT_HOME QKeySequence::MoveToStartOfLine		// Qt::Key_Home
+#define KVI_SHORTCUTS_INPUT_END QKeySequence::MoveToEndOfLine			// Qt::Key_End
+#define KVI_SHORTCUTS_INPUT_HOME_SELECT QKeySequence::SelectStartOfLine		// Qt::ShiftModifier + Qt::Key_Home
+#define KVI_SHORTCUTS_INPUT_END_SELECT QKeySequence::SelectEndOfLine		// Qt::ShiftModifier + Qt::Key_End
+#define KVI_SHORTCUTS_INPUT_HISTORY_PREV QKeySequence::MoveToPreviousLine	// Qt::Key_Up
+#define KVI_SHORTCUTS_INPUT_HISTORY_NEXT QKeySequence::MoveToNextLine		// Qt::Key_Down
 #define KVI_SHORTCUTS_INPUT_RETURN Qt::Key_Return
-#define KVI_SHORTCUTS_INPUT_RETURN_2 Qt::ShiftModifier + Qt::Key_Return
-#define KVI_SHORTCUTS_INPUT_RETURN_3 Qt::Key_Enter
-#define KVI_SHORTCUTS_INPUT_RETURN_4 Qt::ShiftModifier + Qt::Key_Enter
+#define KVI_SHORTCUTS_INPUT_RETURN_2 Qt::Key_Enter
 #define KVI_SHORTCUTS_INPUT_BACKSPACE Qt::Key_Backspace
 #define KVI_SHORTCUTS_INPUT_BACKSPACE_2 Qt::ShiftModifier + Qt::Key_Backspace
-#define KVI_SHORTCUTS_INPUT_DELETE Qt::Key_Delete
+#define KVI_SHORTCUTS_INPUT_DELETE QKeySequence::Delete				// Del
 #define KVI_SHORTCUTS_INPUT_ESCAPE Qt::Key_Escape
-#define KVI_SHORTCUTS_INPUT_ALT Qt::Key_Alt
-#define KVI_SHORTCUTS_INPUT_ALT_2 Qt::Key_Meta
 #define KVI_SHORTCUTS_INPUT_DUMMY Qt::ShiftModifier + Qt::Key_Escape
-#define KVI_SHORTCUTS_INPUT_DUMMY_2 Qt::ShiftModifier + Qt::Key_Delete
-
+#define KVI_SHORTCUTS_WIN_ZOOM_IN QKeySequence::ZoomIn				// Ctrl++
+#define KVI_SHORTCUTS_WIN_ZOOM_OUT QKeySequence::ZoomOut			// Ctrl+-
+#define KVI_SHORTCUTS_WIN_ZOOM_DEFAULT Qt::ControlModifier + Qt::Key_0
 
 /*
 	@doc: keyboard
@@ -213,15 +221,24 @@
 	@short:
 		The list of the common keyboard shortcuts
 	@body:
+		This list contains the key sequences associated to some common actions (like selecting text, etc). Since KVIrc 4.2 the shortcuts are dinamic:
+		[ul]
+		[li]more shortcuts can trigger the same actions: Cut is both Ctrl+X and Shift+Del[/li]
+		[li]shortcuts can be adapted to the os: Help is F1 under Windows and Linux, Ctrl+? on Mac OSX[/li]
+		[/ul]
+		A full list of available combinations is available at the [anchorlink:http://doc.qt.nokia.com/latest/qkeysequence.html#standard-shortcuts] Qt documentation[/anchorlink]
+		[br]
 		[big]All the standard keys alphabetically ordered[/big][br]
 		[b]F1:[/b] Help Index (Window)[br]
 		[b]Ctrl+A:[/b] Select all[br]
 		[b]Ctrl+B:[/b] Insert Bold control character[br]
 		[b]Ctrl+C:[/b] Copy to clipboard[br]
 		[b]Ctrl+F:[/b] Open "Find Text" dialog[br]
+		[b]Ctrl+L:[/b] Scroll to the "last read" line marker[br]
 		[b]Ctrl+I:[/b] Open "Insert icon" dialog[br]
 		[b]Ctrl+J:[/b] Open "Join Channels" dialog[br]
 		[b]Ctrl+K:[/b] Open "Insert Color" dialog[br]
+		[b]Ctrl+L:[/b] Scroll to the last read line[br]
 		[b]Ctrl+N:[/b] Open new context[br]
 		[b]Ctrl+O:[/b] Insert Reset control character[br]
 		[b]Ctrl+P:[/b] Insert "Plain text" control character[br]
@@ -233,6 +250,9 @@
 		[b]Ctrl+X:[/b] Cut to clipboard[br]
 		[b]Ctrl+Y:[/b] Toggle the commandline's KVS/User-friendly mode[br]
 		[b]Ctrl+Z:[/b] Undo last action[br]
+		[b]Ctrl+"+":[/b] Increase font size[br]
+		[b]Ctrl+"-":[/b] Decrease font size[br]
+		[b]Ctrl+0:[/b] Restore default font (and font size)[br]
 		[b]Ctrl+Shift+A:[/b] Go away/back[br]
 		[b]Ctrl+Shift+B:[/b] Open "Manage Toolbars" dialog[br]
 		[b]Ctrl+Shift+C:[/b] Connect/disconnect current irc context[br]
@@ -240,6 +260,8 @@
 		[b]Ctrl+Shift+E:[/b] Open Event editor[br]
 		[b]Ctrl+Shift+I:[/b] Open Identity options[br]
 		[b]Ctrl+Shift+L:[/b] Open Alias editor[br]
+		[b]Ctrl+Shift+M:[/b] Open "Manage Themes" dialog[br]
+		[b]Ctrl+Shift+N:[/b] Open "Manage Addons" dialog[br]
 		[b]Ctrl+Shift+O:[/b] Open "Options" dialog[br]
 		[b]Ctrl+Shift+P:[/b] Open Popup editor[br]
 		[b]Ctrl+Shift+Q:[/b] Open Action editor[br]
@@ -263,6 +285,7 @@
 		[b]PageDown:[/b] Scroll the output window down one page[br]
 		[b]Shift+PageUp:[/b] Scroll the output window up one line[br]
 		[b]Shift+PageDown:[/b] Scroll the output window down one line[br]
+		[b]Ctrl+L:[/b] Scroll to the last read line[br]
 		[b]Ctrl+W:[/b] Close current window[br]
 
 		[big]Text editing related hotkeys:[/big][br]
@@ -294,6 +317,7 @@
 		[b]Shift+RightArrow:[/b] Move the selection to the right[br]
 		[b]Alt+Enter:[/b] Show/hide the multiline editor[br]
 		[b]Ctrl+Enter:[/b] Send message as plain text, ignoring / commands[br]
+		[b]Shift+Enter:[/b] Send message as a kvs command[br]
 		[b]Alt+<numeric_sequence>:[/b] Insert the character by ASCII/Unicode code[br]
 		[example]
 		[b]Alt+32:[/b] Inserts ASCII/Unicode character 32: ' ' (a space)
