@@ -5,9 +5,9 @@
 //   File : libkvisnd.h
 //   Creation date : Thu Dec 27 2002 17:13:12 GMT by Juanjo Alvarez
 //
-//   This file is part of the KVirc irc client distribution
+//   This file is part of the KVIrc irc client distribution
 //   Copyright (C) 2002 Juanjo Alvarez (juanjux at yahoo dot es)
-//   Copyright (C) 2002-2008 Szymon Stefanek (pragma at kvirc dot net)
+//   Copyright (C) 2002-2010 Szymon Stefanek (pragma at kvirc dot net)
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -26,11 +26,11 @@
 //=============================================================================
 
 #include "kvi_settings.h"
-#include "kvi_pointerlist.h"
-#include "kvi_pointerhashtable.h"
-#include "kvi_options.h"
-#include "kvi_thread.h"
-#include "kvi_string.h"
+#include "KviPointerList.h"
+#include "KviPointerHashTable.h"
+#include "KviOptions.h"
+#include "KviThread.h"
+#include "KviCString.h"
 
 #include <QObject>
 
