@@ -3,8 +3,8 @@
 //   File : libkvisystem.cpp
 //   Creation date : Fri Nov 16 03:50:12 2001 GMT by Szymon Stefanek
 //
-//   This system is part of the KVirc irc client distribution
-//   Copyright (C) 2001-2008 Szymon Stefanek (pragma at kvirc dot net)
+//   This system is part of the KVIrc irc client distribution
+//   Copyright (C) 2001-2010 Szymon Stefanek (pragma at kvirc dot net)
 //   Copyright ©        2009 Kai Wasserbäch <debian@carbon-project.org>
 //
 //   This program is FREE software. You can redistribute it and/or
@@ -23,17 +23,17 @@
 //
 //=============================================================================
 
-#include "plugin.h"
+#include "Plugin.h"
 
 #include "kvi_settings.h"
-#include "kvi_module.h"
-#include "kvi_string.h"
-#include "kvi_thread.h"
-#include "kvi_locale.h"
-#include "kvi_app.h"
-#include "kvi_env.h"
-#include "kvi_osinfo.h"
-#include "kvi_modulemanager.h"
+#include "KviModule.h"
+#include "KviCString.h"
+#include "KviThread.h"
+#include "KviLocale.h"
+#include "KviApplication.h"
+#include "KviEnvironment.h"
+#include "KviOsInfo.h"
+#include "KviModuleManager.h"
 
 #include <QClipboard>
 #include <QByteArray>
@@ -44,8 +44,11 @@
 	#include <unistd.h>
 #endif
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_DBUS_SUPPORT
 	#include <QtDBus/QtDBus>
+#endif
+
+#ifdef COMPILE_KDE_SUPPORT
 	#include <KToolInvocation>  // invokeTerminal() for system.runcmd
 #else                           // tools we need to work around the absence of
                                 // invokeTerminal()
@@ -53,7 +56,7 @@
 	#include <QStringList>
 #endif
 
-KviPluginManager * g_pPluginManager;
+PluginManager * g_pPluginManager;
 
 /*
 	@doc: system.ostype
@@ -212,7 +215,7 @@ static bool system_kvs_fnc_getenv(KviKvsModuleFunctionCall *c)
 	c->returnValue()->setString(env.isEmpty() ? QString::fromLocal8Bit(env) : QString::fromLocal8Bit(def));
 #else
 */
-	char * b = kvi_getenv(szVar.data());
+	char * b = KviEnvironment::getVariable(szVar.data());
 	c->returnValue()->setString(b ? QString::fromLocal8Bit(b) : QString());
 //#endif
 	return true;
@@ -413,25 +416,27 @@ static bool system_kvs_fnc_hostname(KviKvsModuleFunctionCall *c)
 	@short:
 		Performs a DBus call
 	@syntax:
-		<variant> $system.dbus(<service:string>,<path:string>,<interface:string>,<method:string>[,<parameter1:string>[,<parameter2:string>[,...]]])
+		<variant> $system.dbus(<service:string>,<path:string>,<interface:string>,<method:string>[,<bus_type:string>[,<parameter1:string>[,<parameter2:string>[,...]]]])
 	@description:
 		This function allows performing simple Dbus calls without executing
-		an external process. This feature is available ONLY when KDE support
-		is compiled in the executable: this means that this function is absolutely
+		an external process. This feature is available ONLY under unix: 
+		this means that this function is absolutely
 		non portable (don't use it in scripts that you're going to distribute).
 		<application> is the name of the application being called, <objectid> is the
 		identifier of the object called, <function> is the function to be executed
 		on the remote object and <parameter1>,<parameter2>,... is the list of
 		parameters to be passed. The <function> name must contain the
 		trailing parenthesis and parameter specification (see examples).
+		The <bus_type> specifies the bus to connect, use "system" for systemBus or
+		"session" for sessionBus. If it's leaved blank, it will use sessionBus.
 		The parameters MUST be in the form "type=value"
 		where "type" is the C++ type of the parameter and value
-		is the string rappresentation of the parameter data. Currently
+		is the string representation of the parameter data. Currently
 		KVIrc supports only QString,QByteArray,bool,int and uint data types.[br]
-		The returned value is the string rappresentation of the returned
+		The returned value is the string representation of the returned
 		data if the return type is known, otherwise it is the name of the data type returned.
 		[br]
-		If the application name is prefixed with "?" then the call is performed in "remote test"
+		If the service name is prefixed with "?" then the call is performed in "remote test"
 		mode: no "remote" errors are printed and the function returns 1 if the call executed
 		successfully and 0 if the call failed. This can be used with the very first
 		call to programmaticaly test if the remote application is running.
@@ -450,31 +455,66 @@ static bool system_kvs_fnc_hostname(KviKvsModuleFunctionCall *c)
 
 static bool system_kvs_fnc_dbus(KviKvsModuleFunctionCall *c)
 {
-	QString szService, szPath, szInterface, szMethod;
+	QString szService, szPath, szInterface, szMethod, szBusType;
 	QStringList parms;
+	bool bRemoteTest=false;
 
 	KVSM_PARAMETERS_BEGIN(c)
 		KVSM_PARAMETER("service",KVS_PT_NONEMPTYSTRING,0,szService)
 		KVSM_PARAMETER("path",KVS_PT_NONEMPTYSTRING,0,szPath)
 		KVSM_PARAMETER("interface",KVS_PT_NONEMPTYSTRING,0,szInterface)
 		KVSM_PARAMETER("method",KVS_PT_NONEMPTYSTRING,0,szMethod)
+		KVSM_PARAMETER("bus_type",KVS_PT_STRING,KVS_PF_OPTIONAL,szBusType)
 		KVSM_PARAMETER("parameter_list",KVS_PT_STRINGLIST,KVS_PF_OPTIONAL,parms)
 	KVSM_PARAMETERS_END(c)
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_DBUS_SUPPORT
 
-	QDBusInterface remoteApp(szService, szPath, szInterface);
+	if(szBusType.isEmpty())
+		szBusType = "session";
+
+	QDBusConnection busType("");
+	
+	if(szBusType == "system")
+	{
+		busType = QDBusConnection::systemBus();
+	} else if(szBusType == "session"){
+		busType = QDBusConnection::sessionBus();
+	} else {
+		c->warning(__tr2qs("No DBus type specified"));
+		return false;
+	}
+	
+	if(szService.left(1).compare("?")==0)
+	{
+		szService.remove(0,1);
+		bRemoteTest=true;
+	}
+
+	QDBusInterface remoteApp(szService, szPath, szInterface, busType);
 	if(!remoteApp.isValid())
 	{
+		if(bRemoteTest)
+		{
+			c->returnValue()->setInteger(0);
+			return true;
+		} else {
 			c->warning(__tr2qs("Invalid DBus interface"));
 			return false;
+		}
+	}
+
+	if(bRemoteTest)
+	{
+		c->returnValue()->setInteger(1);
+		return true;
 	}
 
 	QList<QVariant> ds;
 
 	for ( QStringList::Iterator it = parms.begin(); it != parms.end(); ++it )
 	{
-		KviStr tmp = *it;
+		KviCString tmp = *it;
 
 		if(tmp.isEmpty())
 		{
@@ -482,7 +522,7 @@ static bool system_kvs_fnc_dbus(KviKvsModuleFunctionCall *c)
 			return false;
 		}
 
-		KviStr szType = tmp.leftToFirst('=',false);
+		KviCString szType = tmp.leftToFirst('=',false);
 		tmp.cutToFirst('=',true);
 		if(szType.isEmpty())szType = "int";
 		bool bOk;
@@ -574,7 +614,7 @@ static bool system_kvs_fnc_dbus(KviKvsModuleFunctionCall *c)
 	}
 
 #else
-		c->warning(__tr2qs("DBus calls are available only when KDE support is compiled in"));
+		c->warning(__tr2qs("DBus calls are available only under UNIX"));
 #endif
 	return true;
 }
@@ -594,7 +634,7 @@ static bool system_kvs_fnc_dbus(KviKvsModuleFunctionCall *c)
 		system.setenv <variable:string> [<value:string>]
 	@description:
 		Sets the enviroinement <variable> to the <value> string.[br]
-		If <value> is not given , the <variable> is unset.[br]
+		If <value> is not given, the <variable> is unset.[br]
 	@seealso:
 		[fnc]$system.getenv[/fnc]
 */
@@ -612,7 +652,7 @@ static bool system_kvs_cmd_setenv(KviKvsModuleCommandCall * c)
 	QByteArray szVar = szVariable.toLocal8Bit();
 	QByteArray szVal = szValue.toLocal8Bit();
 
-	if(szVal.isEmpty())kvi_unsetenv(szVar.data());
+	if(szVal.isEmpty())KviEnvironment::unsetVariable(szVar.data());
 	else
 	{
 /*#ifdef COMPILE_ON_WINDOWS
@@ -621,8 +661,8 @@ static bool system_kvs_cmd_setenv(KviKvsModuleCommandCall * c)
 		Var			=	szVal.data();
 		VarAndVal	=	Var+"="+Val;
 		putenv(VarAndVal);
-#else*/ // <-- this stuff is implicit in kvi_setenv: that's why we have the kvi_ version.
-		kvi_setenv(szVar.data(),szVal.data());
+#else*/ // <-- this stuff is implicit in KviEnvironment::setVariable: that's why we have the kvi_ version.
+		KviEnvironment::setVariable(szVar.data(),szVal.data());
 /*#endif*/
 	}
 	return true;
@@ -674,21 +714,26 @@ static bool system_kvs_fnc_plugin_call(KviKvsModuleFunctionCall *c)
 }
 
 /*
-    @doc: system.runcmd
-    @type:
-        command
-    @title:
-        system.runcmd
-    @short:
-        Runs the specified command in a terminal
-    @syntax:
-        system.runcmd <command:string>
-    @description:
-        Tries to run the given command in the system's default (X)
-        terminal (emulator).
-        [br]
-        [br]
-        [b]Warning: Execute only harmless commands through this![/b]
+	@doc: system.runcmd
+	@type:
+		command
+	@title:
+		system.runcmd
+	@short:
+		Runs the specified command in a terminal
+	@syntax:
+		system.runcmd [-t <terminal:string>] <command:string>
+	@switches:
+		!sw: -t=<terminal> | --terminal=<terminal>
+		Use the specified terminal to launch the command instead
+		of the auto-detected one.
+	@description:
+		Tries to run the given command in the system's default (X)
+		terminal (emulator) or in the terminal specified by the -t
+		option.
+		[br]
+		[br]
+		[b]Warning: Execute only harmless commands through this![/b]
 	@examples:
 		[example]
 			system.runcmd "ping $0"
@@ -703,39 +748,60 @@ static bool system_kvs_cmd_runcmd(KviKvsModuleCommandCall *c)
 		KVSM_PARAMETER("command",KVS_PT_NONEMPTYSTRING,KVS_PF_APPENDREMAINING,szCommand)
 	KVSM_PARAMETERS_END(c)
 
-	// check for empty szCommand
-	if(!szCommand.isEmpty())
+	if(szCommand.isEmpty())
+		return c->error(__tr2qs("No command specified"));
+
+	QString szTerminal;
+	QStringList args;
+	QProcess oProc;
+
+#if defined(COMPILE_ON_WINDOWS) || defined(COMPILE_ON_MINGW)           // Only »cmd.exe /k« in the list.
+	args << "/k" << szCommand;
+#elif defined(COMPILE_ON_MAC)
+	args << "-e" << QString("tell application \"Terminal\" to do script \"%1\"").arg(szCommand);
+#else
+	args << "-e" << szCommand;
+#endif // endif COMPILE_ON_WINDOWS
+
+	if(c->switches()->getAsStringIfExisting('t',"terminal",szTerminal))
 	{
-		QByteArray szCmd = szCommand.toLocal8Bit();
+		if(!oProc.startDetached(szTerminal,args))
+			return c->error(__tr2qs("Failed to start the terminal program"));
+		return true;
+	}
+
+
+
 #ifdef COMPILE_KDE_SUPPORT          // We have invokeTerminal().
-		KToolInvocation::invokeTerminal(szCmd.data());
+
+	KToolInvocation::invokeTerminal(szCommand.toLocal8Bit());
+
 #else                               // No invokeTerminal() for us, we'll use a
                                     // combination of QStringList and QProcess.
-
-		QProcess oProc;
-		QStringList args;
-		QStringList szTerminals;
+	QStringList szTerminals;
 #if defined(COMPILE_ON_WINDOWS) || defined(COMPILE_ON_MINGW)           // Only »cmd.exe /k« in the list.
-		szTerminals.append("cmd.exe");
-		args << "/k" << szCommand;
+	szTerminals.append("cmd.exe");
+#elif defined(COMPILE_ON_MAC)
+	szTerminals.append("osascript");
 #else
-		// List: x-terminal-emulator, terminal, xterm
-		szTerminals.append("x-terminal-emulator");
-		szTerminals.append("terminal");
-		szTerminals.append("xterm");
-		args << "-e" << szCommand;
+	// Where the heck is xdg-terminal?
+	// List: gnome-terminal, x-terminal-emulator, terminal, xterm
+	szTerminals.append("gnome-terminal");
+	szTerminals.append("x-terminal-emulator");
+	szTerminals.append("terminal");
+	szTerminals.append("xterm");
 #endif                              // endif COMPILE_ON_WINDOWS
 
-		QString szTerm;
-		while(!szTerminals.isEmpty())
-		{
-			szTerm=szTerminals.takeFirst();
-			if (oProc.startDetached(szTerm, args))
-				break;
-		}
-#endif                              // endif COMPILE_KDE_SUPPORT
+	QString szTerm;
+	while(!szTerminals.isEmpty())
+	{
+		szTerm=szTerminals.takeFirst();
+		if(oProc.startDetached(szTerm, args))
+			return true;
 	}
-	return true;
+#endif                              // endif COMPILE_KDE_SUPPORT
+
+	return c->error(__tr2qs("Failed to start the terminal program"));
 }
 
 static bool system_module_init(KviModule * m)
@@ -759,7 +825,7 @@ static bool system_module_init(KviModule * m)
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"setSelection",system_kvs_cmd_setSelection);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"runcmd",system_kvs_cmd_runcmd);
 
-	g_pPluginManager = new(KviPluginManager);
+	g_pPluginManager = new(PluginManager);
 
 	return true;
 }
