@@ -3,7 +3,7 @@
 //   File : libkvitrayicon.cpp
 //   Creation date : Tue Jan 02 2001 14:34:12 CEST by Szymon Stefanek
 //
-//   This file is part of the KVirc irc client distribution
+//   This file is part of the KVIrc irc client distribution
 //   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
 //   Copyright (C) 2007 Alexey Uzhva (wizard at opendoor dot ru)
 //   Copyright (C) 2008 Elvio Basello (hellvis69 at netsons dot org)
@@ -27,48 +27,51 @@
 #include "libkvitrayicon.h"
 
 #include "kvi_settings.h"
-#include "kvi_app.h"
-#include "kvi_module.h"
-#include "kvi_locale.h"
-#include "kvi_memmove.h"
-#include "kvi_windowlist.h"
-#include "kvi_window.h"
-#include "kvi_dynamictooltip.h"
-#include "kvi_iconmanager.h"
-#include "kvi_internalcmd.h"
-#include "kvi_console.h"
-#include "kvi_ircconnection.h"
-#include "kvi_ircconnectionuserinfo.h"
-#include "kvi_options.h"
-#include "kvi_ircview.h"
-#include "kvi_tal_popupmenu.h"
+#include "KviApplication.h"
+#include "KviModule.h"
+#include "KviLocale.h"
+#include "KviMemory.h"
+#include "KviWindowListBase.h"
+#include "KviWindow.h"
+#include "KviDynamicToolTip.h"
+#include "KviIconManager.h"
+#include "KviInternalCommand.h"
+#include "KviConsoleWindow.h"
+#include "KviIrcConnection.h"
+#include "KviIrcConnectionUserInfo.h"
+#include "KviOptions.h"
+#include "KviIrcView.h"
 
 #include <QPixmap>
 #include <QPainter>
 #include <QTimer>
 #include <QEvent>
 #include <QRegExp>
+#include <QWidgetAction>
+#include <QMenu>
 
 #include <stdlib.h>
 #include <time.h>
 
 #if defined(COMPILE_ON_WINDOWS) || defined(COMPILE_ON_MINGW)
 	#define ICON_SIZE 16
+	#include <Windows.h>
 #else
 	#define ICON_SIZE 22
 #endif
 
 extern KVIRC_API KviPointerHashTable<QString,KviWindow> * g_pGlobalWindowDict;
-static KviPointerList<KviTrayIcon> * g_pTrayIconList = 0;
+static KviTrayIconWidget * g_pTrayIcon = 0;
 
 static QPixmap * g_pDock1 = 0;
 static QPixmap * g_pDock2 = 0;
 static QPixmap * g_pDock3 = 0;
 
-KviTrayIcon::KviTrayIcon(KviFrame * frm)
-: QSystemTrayIcon(frm), m_CurrentPixmap(ICON_SIZE,ICON_SIZE)
+KviTrayIconWidget::KviTrayIconWidget()
+: QSystemTrayIcon(g_pMainWindow), m_CurrentPixmap(ICON_SIZE,ICON_SIZE)
 {
-	m_pContextPopup = new KviTalPopupMenu(0);
+	g_pTrayIcon = this;
+    m_pContextPopup = new QMenu(0);
 	setContextMenu(m_pContextPopup);
 
 	m_iConsoles = 0;
@@ -80,37 +83,39 @@ KviTrayIcon::KviTrayIcon(KviFrame * frm)
 	m_pFlashingTimer->setObjectName("flashing_timer");
 	connect( m_pFlashingTimer, SIGNAL(timeout()), this, SLOT(flashingTimerShot()) );
 	m_bFlashed=0;
-	g_pTrayIconList->append(this);
-	m_pFrm = frm;
-	m_pFrm->setDockExtension(this);
 
-	m_pTip = new KviDynamicToolTip(frm,"dock_tooltip");
-	m_pAwayPopup = new KviTalPopupMenu(0);
+	g_pMainWindow->setTrayIcon(this);
+
+	m_pTip = new KviDynamicToolTip(g_pMainWindow,"dock_tooltip");
+    m_pAwayPopup = new QMenu(0);
 
 	m_pTitleLabel = new QLabel(__tr2qs("<b>KVIrc</b>"),m_pContextPopup);
 	QPalette p;
 	m_pTitleLabel->setStyleSheet("background-color: " + p.color(QPalette::Normal, QPalette::Mid).name());
-	m_pContextPopup->insertItem(m_pTitleLabel);
+	QWidgetAction * pAction = new QWidgetAction(this);
+	pAction->setDefaultWidget(m_pTitleLabel); 
+	m_pContextPopup->addAction(pAction); 
+
 	m_pContextPopup->setWindowTitle(__tr2qs("Context"));
 	m_pAwayMenuId = m_pContextPopup->addMenu(m_pAwayPopup);
-	m_pAwayMenuId->setIcon(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_AWAY)));
+	m_pAwayMenuId->setIcon(*(g_pIconManager->getSmallIcon(KviIconManager::Away)));
 	m_pAwayMenuId->setText(__tr2qs("Away"));
 
-	QAction* id = m_pContextPopup->addAction(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_OPTIONS)),__tr2qs("&Configure KVIrc..."),this,SLOT(executeInternalCommand(bool)));
+	QAction* id = m_pContextPopup->addAction(*(g_pIconManager->getSmallIcon(KviIconManager::Options)),__tr2qs("&Configure KVIrc..."),this,SLOT(executeInternalCommand(bool)));
 	id->setData(KVI_INTERNALCOMMAND_OPTIONS_DIALOG);
 
-	id = m_pContextPopup->addAction(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)),__tr2qs("&About KVIrc"),this,SLOT(executeInternalCommand(bool)));
+	id = m_pContextPopup->addAction(*(g_pIconManager->getSmallIcon(KviIconManager::KVIrc)),__tr2qs("&About KVIrc"),this,SLOT(executeInternalCommand(bool)));
 	id->setData(KVI_INTERNALCOMMAND_ABOUT_ABOUTKVIRC);
 
-	m_pContextPopup->insertSeparator();
-	m_pToggleFrame = m_pContextPopup->addAction(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_RAW)),__tr2qs("Hide/Show"),this,SLOT(toggleParentFrame()));
+    m_pContextPopup->addSeparator();
+	m_pToggleFrame = m_pContextPopup->addAction(*(g_pIconManager->getSmallIcon(KviIconManager::Raw)),__tr2qs("Hide/Show"),this,SLOT(toggleParentFrame()));
 
-	m_pContextPopup->insertSeparator();
+    m_pContextPopup->addSeparator();
 
-	id = m_pContextPopup->addAction(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TRAYICON)),__tr2qs("Un&dock"),this,SLOT(executeInternalCommand(bool)));
+	id = m_pContextPopup->addAction(*(g_pIconManager->getSmallIcon(KviIconManager::TrayIcon)),__tr2qs("Un&dock"),this,SLOT(executeInternalCommand(bool)));
 	id->setData(KVI_INTERNALCOMMAND_TRAYICON_HIDE);
 
-	id = m_pContextPopup->addAction(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUITAPP)),__tr2qs("&Quit"),g_pFrame,SLOT(close()),QKeySequence(Qt::CTRL + Qt::Key_Q));
+	id = m_pContextPopup->addAction(*(g_pIconManager->getSmallIcon(KviIconManager::QuitApp)),__tr2qs("&Quit"),g_pMainWindow,SLOT(close()),QKeySequence(Qt::CTRL + Qt::Key_Q));
 
 	connect(m_pContextPopup,SIGNAL(aboutToShow()),this,SLOT(fillContextPopup()));
 
@@ -120,10 +125,10 @@ KviTrayIcon::KviTrayIcon(KviFrame * frm)
 }
 
 
-KviTrayIcon::~KviTrayIcon()
+KviTrayIconWidget::~KviTrayIconWidget()
 {
-	m_pFrm->setDockExtension(0);
-	g_pTrayIconList->removeRef(this);
+	g_pTrayIcon=0;
+	g_pMainWindow->setTrayIcon(0);
 	delete m_pAwayPopup;
 	delete m_pTitleLabel;
 	delete m_pTip;
@@ -132,20 +137,20 @@ KviTrayIcon::~KviTrayIcon()
 }
 
 
-void KviTrayIcon::executeInternalCommand(bool)
+void KviTrayIconWidget::executeInternalCommand(bool)
 {
 	int iCmd;
 	bool bOk;
 	iCmd=(((QAction*)QObject::sender())->data()).toInt(&bOk);
-	if(m_pFrm && bOk)
-		m_pFrm->executeInternalCommand(iCmd);
+	if(bOk)
+		g_pMainWindow->executeInternalCommand(iCmd);
 }
-void KviTrayIcon::die()
+void KviTrayIconWidget::die()
 {
 	delete this;
 }
 
-void KviTrayIcon::flashingTimerShot()
+void KviTrayIconWidget::flashingTimerShot()
 {
 	m_bFlashed=!m_bFlashed;
 	refresh();
@@ -155,36 +160,37 @@ void KviTrayIcon::flashingTimerShot()
 
 static const char * idlemsgs[NIDLEMSGS]=
 {
-	__tr("Nothing is happening...") ,
-	__tr("Just idling...") ,
-	__tr("Dum de dum de dum...") ,
-	__tr("Hey man... do something!") ,
-	__tr("Umpf!") ,
-	__tr("Silence speaking") ,
-	__tr("Are ya here?") ,
-	__tr("The world has stopped?") ,
-	__tr("Everything is all right") ,
-	__tr("idle()") ,
-	__tr("It's so cold here...") ,
-	__tr("Do not disturb... watching TV") ,
-	__tr("Just vegetating") ,
-	__tr("Hey... are ya sure that your network is up?") ,
-	__tr("Seems like the world has stopped spinning") ,
-	__tr("This silence is freaking me out!") ,
-	__tr("Mieeeeeowww!") ,
+	__tr("Nothing is happening..."),
+	__tr("Just idling..."),
+	__tr("Dum de dum de dum..."),
+	__tr("Hey man... do something!"),
+	__tr("Umpf!"),
+	__tr("Silence speaking"),
+	__tr("Are ya here?"),
+	__tr("The world has stopped?"),
+	__tr("Everything is all right"),
+	__tr("idle()"),
+	__tr("It's so cold here..."),
+	__tr("Do not disturb... watching TV"),
+	__tr("Just vegetating"),
+	__tr("Hey... are ya sure that your network is up?"),
+	__tr("Seems like the world has stopped spinning"),
+	__tr("This silence is freaking me out!"),
+	__tr("Mieeeeeowww!"),
 	__tr("idle idle idle idle!")
 };
 
-bool KviTrayIcon::event(QEvent *e)
+bool KviTrayIconWidget::event(QEvent *e)
 {
 	if(e->type()==QEvent::ToolTip)
 	{
-		QPoint pos= m_pFrm->mapFromGlobal(QCursor::pos());
+		QPoint pos= g_pMainWindow->mapFromGlobal(QCursor::pos());
 		QString tmp;
 
-		KviWindowListBase * t = m_pFrm->windowListWidget();
+		KviWindowListBase * t = g_pMainWindow->windowListWidget();
 
 		QString line;
+		bool first = true;
 
 		for(KviWindowListItem * b = t->firstItem();b;b = t->nextItem())
 		{
@@ -196,6 +202,9 @@ bool KviTrayIcon::event(QEvent *e)
 					line = b->kviWindow()->lastMessageText();
 					if(!line.isEmpty())
 					{
+						if(!first)tmp += "<br><br>\n";
+						else first = false;
+
 						line.replace(QChar('&'),"&amp;");
 						line.replace(QChar('<'),"&lt;");
 						line.replace(QChar('>'),"&gt;");
@@ -203,7 +212,6 @@ bool KviTrayIcon::event(QEvent *e)
 						tmp += b->kviWindow()->plainTextCaption();
 						tmp += "</b><br>";
 						tmp += line;
-						tmp += "<br><br>\n";
 					}
 				}
 			}
@@ -222,14 +230,14 @@ bool KviTrayIcon::event(QEvent *e)
 	return false;
 }
 
-//int KviTrayIcon::message(int,void *)
+//int KviTrayIconWidget::message(int,void *)
 //{
-//	debug("Message");
+//	qDebug("Message");
 //	update();
 //	return 0;
 //}
 
-void KviTrayIcon::doAway(bool)
+void KviTrayIconWidget::doAway(bool)
 {
 	int id;
 	bool ok;
@@ -249,9 +257,9 @@ void KviTrayIcon::doAway(bool)
 		KviPointerHashTableIterator<QString,KviWindow> it(*g_pGlobalWindowDict);
 		while(KviWindow * wnd = it.current())
 		{
-			if(wnd->type()==KVI_WINDOW_TYPE_CONSOLE)
+			if(wnd->type()==KviWindow::Console)
 			{
-				KviConsole* pConsole=(KviConsole*)wnd;
+				KviConsoleWindow* pConsole=(KviConsoleWindow*)wnd;
 				if(pConsole->isConnected())
 				{
 					if(id==-2)
@@ -267,7 +275,7 @@ void KviTrayIcon::doAway(bool)
  			++it;
 		}
 	} else {
-		KviConsole* pConsole=g_pApp->findConsole((unsigned int)id);
+		KviConsoleWindow* pConsole=g_pApp->findConsole((unsigned int)id);
 		if(pConsole)
 		{
 			if(pConsole->isConnected())
@@ -285,18 +293,18 @@ void KviTrayIcon::doAway(bool)
 	}
 }
 
-void KviTrayIcon::fillContextPopup()
+void KviTrayIconWidget::fillContextPopup()
 {
-	m_pToggleFrame->setText(m_pFrm->isVisible() ? __tr2qs("Hide Window") : __tr2qs("Show Window"));
+	m_pToggleFrame->setText(g_pMainWindow->isVisible() ? __tr2qs("Hide Window") : __tr2qs("Show Window"));
 	if(g_pApp->topmostConnectedConsole())
 	{
 		m_pAwayMenuId->setVisible(true);
 		m_pAwayPopup->clear();
 
-		QAction* pAllAway=m_pAwayPopup->addAction(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Away on all"),this,SLOT(doAway(bool)));
+		QAction * pAllAway = m_pAwayPopup->addAction(*(g_pIconManager->getSmallIcon(KviIconManager::Console)),__tr2qs("Away on all"),this,SLOT(doAway(bool)));
 		pAllAway->setData(-1);
 
-		QAction* pAllUnaway=m_pAwayPopup->addAction(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Back on all"),this,SLOT(doAway(bool)));
+		QAction * pAllUnaway = m_pAwayPopup->addAction(*(g_pIconManager->getSmallIcon(KviIconManager::Console)),__tr2qs("Back on all"),this,SLOT(doAway(bool)));
 		pAllUnaway->setData(-2);
 
 		QAction* pSeparator=m_pAwayPopup->addSeparator();
@@ -307,19 +315,19 @@ void KviTrayIcon::fillContextPopup()
 		int iNetCount=0;
 		while(KviWindow * wnd = it.current())
 		{
-			if(wnd->type()==KVI_WINDOW_TYPE_CONSOLE)
+			if(wnd->type()==KviWindow::Console)
 			{
-				KviConsole* pConsole=(KviConsole*)wnd;
+				KviConsoleWindow* pConsole=(KviConsoleWindow*)wnd;
 				if(pConsole->isConnected())
 				{
 					QAction* id;
 					if(pConsole->connection()->userInfo()->isAway())
 					{
-						id=m_pAwayPopup->addAction(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Back on %1").arg(pConsole->currentNetworkName()),this,SLOT(doAway(bool)));
+						id=m_pAwayPopup->addAction(*(g_pIconManager->getSmallIcon(KviIconManager::Console)),__tr2qs("Back on %1").arg(pConsole->currentNetworkName()),this,SLOT(doAway(bool)));
 						id->setData(pConsole->context()->id());
 						bAllUnaway=0;
 					} else {
-						id=m_pAwayPopup->addAction(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Away on %1").arg(pConsole->currentNetworkName()),this,SLOT(doAway(bool)));
+						id=m_pAwayPopup->addAction(*(g_pIconManager->getSmallIcon(KviIconManager::Console)),__tr2qs("Away on %1").arg(pConsole->currentNetworkName()),this,SLOT(doAway(bool)));
 						id->setData(pConsole->context()->id());
 						bAllAway=0;
 					}
@@ -343,28 +351,52 @@ void KviTrayIcon::fillContextPopup()
 	}
 }
 
-void KviTrayIcon::toggleParentFrame()
+void KviTrayIconWidget::toggleParentFrame()
 {
-	if(m_pFrm->isMinimized())
+	qDebug("TrayIcon::toggleParentFrame()");
+	if(g_pMainWindow->isMinimized())
 	{
-		m_pFrm->setWindowState(m_pFrm->windowState() & (~Qt::WindowMinimized | Qt::WindowActive));
+		qDebug("- frame is minimized");
+		g_pMainWindow->setWindowState(g_pMainWindow->windowState() & (~Qt::WindowMinimized | Qt::WindowActive));
 
 		if(KVI_OPTION_BOOL(KviOption_boolFrameIsMaximized))
-			m_pFrm->showMaximized();
-		else m_pFrm->show();
-	} else if(!m_pFrm->isVisible())
+		{
+			qDebug("- window was maximized so calling showMaximized()");
+			g_pMainWindow->showMaximized();
+		} else {
+			qDebug("- window wasn't maximized so calling plain show()");
+			g_pMainWindow->show();
+		}
+#if defined(COMPILE_ON_WINDOWS) || defined(COMPILE_ON_MINGW)
+		// raise it
+		SetForegroundWindow((HWND)g_pMainWindow->winId());
+		g_pMainWindow->activateWindow();
+#endif
+	} else if(!g_pMainWindow->isVisible())
 	{
+		qDebug("- frame is not visible");
 		//restore mainwindow
 		if(KVI_OPTION_BOOL(KviOption_boolFrameIsMaximized))
-			m_pFrm->showMaximized();
-		else m_pFrm->show();
+		{
+			qDebug("- window was maximized so calling showMaximized()");
+			g_pMainWindow->showMaximized();
+		} else {
+			qDebug("- window wasn't maximized so calling plain show()");
+			g_pMainWindow->show();
+		}
+#if defined(COMPILE_ON_WINDOWS) || defined(COMPILE_ON_MINGW)
+		// raise it
+		SetForegroundWindow((HWND)g_pMainWindow->winId());
+		g_pMainWindow->activateWindow();
+#endif
 	} else {
-		KVI_OPTION_BOOL(KviOption_boolFrameIsMaximized) = m_pFrm->isMaximized();
-		m_pFrm->hide();
+		qDebug("- frame is visible: maximized state=%d, hiding",g_pMainWindow->isMaximized());
+		KVI_OPTION_BOOL(KviOption_boolFrameIsMaximized) = g_pMainWindow->isMaximized();
+		g_pMainWindow->hide();
 	}
 }
 
-void KviTrayIcon::refresh()
+void KviTrayIconWidget::refresh()
 {
 	grabActivityInfo();
 
@@ -383,7 +415,7 @@ void KviTrayIcon::refresh()
 
 	if(m_bFlashed)
 	{
-		thisRestrictionOfQt4IsNotNice.drawPixmap((ICON_SIZE-16)/2,(ICON_SIZE-16)/2,16,16,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MESSAGE)),0,0,16,16);
+		thisRestrictionOfQt4IsNotNice.drawPixmap((ICON_SIZE-16)/2,(ICON_SIZE-16)/2,16,16,*(g_pIconManager->getSmallIcon(KviIconManager::Message)),0,0,16,16);
 	} else {
 		thisRestrictionOfQt4IsNotNice.drawPixmap(0,0,ICON_SIZE/2,ICON_SIZE/2,
 			m_iOther ?
@@ -411,17 +443,33 @@ void KviTrayIcon::refresh()
 	updateIcon();
 }
 
-void KviTrayIcon::activatedSlot( QSystemTrayIcon::ActivationReason reason )
+void KviTrayIconWidget::activatedSlot( QSystemTrayIcon::ActivationReason reason )
 {
-	if(reason==QSystemTrayIcon::Trigger && (KVI_OPTION_BOOL(KviOption_boolCloseInTray) || !m_pFrm->isVisible()))
+	switch(reason)
 	{
-		toggleParentFrame();
+		case QSystemTrayIcon::Trigger:
+			// This is single click
+#ifdef COMPILE_ON_MAC
+			// On MacOSX one can only single-left-click the icon.
+			// This activates the context menu and is quite confusing if it *also* hides the kvirc window.
+			// So on mac we only _show_ the main window if it's hidden and the CloseInTray option is enabled.
+			if((KVI_OPTION_BOOL(KviOption_boolCloseInTray) || KVI_OPTION_BOOL(KviOption_boolMinimizeInTray))
+				&& ((!g_pMainWindow->isVisible()) || g_pMainWindow->isMinimized()))
+				toggleParentFrame();
+#else //!COMPILE_ON_MAC
+			// on other platforms we always toggle the window
+			toggleParentFrame();
+#endif //!COMPILE_ON_MAC
+		break;
+		default:
+			// we do nothing at this time
+		break;
 	}
 }
 
-void KviTrayIcon::grabActivityInfo()
+void KviTrayIconWidget::grabActivityInfo()
 {
-	KviWindowListBase * t = m_pFrm->windowListWidget();
+	KviWindowListBase * t = g_pMainWindow->windowListWidget();
 
 	if(KVI_OPTION_BOOL(KviOption_boolUseLevelBasedTrayNotification))
 	{
@@ -447,13 +495,13 @@ void KviTrayIcon::grabActivityInfo()
 			unsigned int iLevel = b->highlightLevel();
 			switch(b->kviWindow()->type())
 			{
-				case KVI_WINDOW_TYPE_CONSOLE:
+				case KviWindow::Console:
 					if(m_iConsoles < iLevel) m_iConsoles = iLevel;
 				break;
-				case KVI_WINDOW_TYPE_CHANNEL:
+				case KviWindow::Channel:
 					if(m_iChannels < iLevel) m_iChannels = iLevel;
 				break;
-				case KVI_WINDOW_TYPE_QUERY:
+				case KviWindow::Query:
 					if(m_iQueries < iLevel) m_iQueries = iLevel;
 				break;
 				default:
@@ -474,13 +522,13 @@ void KviTrayIcon::grabActivityInfo()
 				if(iLevel>0)
 				switch(b->kviWindow()->type())
 				{
-					case KVI_WINDOW_TYPE_CONSOLE:
+					case KviWindow::Console:
 						if(m_iConsoles < iLevel) m_iConsoles = iLevel;
 					break;
-					case KVI_WINDOW_TYPE_CHANNEL:
+					case KviWindow::Channel:
 						if(m_iChannels < iLevel) m_iChannels = iLevel;
 					break;
-					case KVI_WINDOW_TYPE_QUERY:
+					case KviWindow::Query:
 						if(m_iQueries < iLevel) m_iQueries = iLevel;
 					break;
 					default:
@@ -511,21 +559,11 @@ void KviTrayIcon::grabActivityInfo()
 	}
 }
 
-void KviTrayIcon::updateIcon()
+void KviTrayIconWidget::updateIcon()
 {
 	setIcon(QIcon(m_CurrentPixmap));
 }
 
-static KviTrayIcon * trayicon_find(KviFrame *f)
-{
-	if(!g_pTrayIconList)return 0;
-	for(KviTrayIcon * w = g_pTrayIconList->first();w;w = g_pTrayIconList->next())
-	{
-		if(w->frame() == f)return w;
-	}
-	return 0;
-}
-
 /*
 	@doc: trayicon.show
 	@type:
@@ -533,38 +571,35 @@ static KviTrayIcon * trayicon_find(KviFrame *f)
 	@title:
 		trayicon.show
 	@short:
-		Shows the dock widget for the current frame window
+		Shows the tray icon (dock widget)
 	@keyterms:
-		dock widget , system tray
+		dock widget, system tray
 	@syntax:
 		trayicon.show
 	@description:
-		Shows the dock widget for the current frame window.[br]
-		The dock widget is a small widget that docks in the KDE panel.[br]
-		It shows a small icon of the earth and eventually displays four squares
+		Shows the tray icon (sometimes called dock widget).[br]
+		The tray icon is a small widget that docks in the window manager panel.[br]
+		It shows a small kvirc icon and eventually displays four squares
 		that cover this icon: the bottom left square appears when there is some new
 		text in any console window, the square becomes red if the text is highlighted.[br]
 		The bottom right square appears when there is some new text in any channel window,
 		and it becomes red when the text is highlighted.[br] The upper right square refers to
-		query windows and the upper left one to any other kind of window (dcc , links...).[br]
-		If you move the mouse over the dock widget a tooltip will show you the last lines
+		query windows and the upper left one to any other kind of window (dcc, links...).[br]
+		If you move the mouse over the tray icon a tooltip will show you the last lines
 		of the "new" text in all these windows.[br]
 		This is useful when you keep the main KVIrc window minimized and you're working on something else:
-		if the dock widget shows nothing but the earth icon , nothing is happening in the main KVIrc window.
-		If the dock widget shows one or more white (or red) squares , you can move the mouse over
-		and check what's happened exactly and eventually bring up the main KVIrc window by clicking on the widget.[br]
-		[big]tecnical details[/big]
-		The dock widget is currently working in KDE compilation mode only:
-		it relies on the KWin implementation of the Window Manager interaction protocol.
+		if the tray icon shows nothing but the kvirc icon, nothing is happening in the main KVIrc window.
+		If the tray icon shows one or more white (or red) squares, you can move the mouse over
+		and check what's happened exactly and eventually bring up the main KVIrc window by clicking on the icon.[br]
 	@seealso:
 		[cmd]trayicon.hide[/cmd]
 */
 
-static bool trayicon_kvs_cmd_show(KviKvsModuleCommandCall * c)
+static bool trayicon_kvs_cmd_show(KviKvsModuleCommandCall *)
 {
-	if(!(trayicon_find(c->window()->frame())))
+	if(g_pTrayIcon==0)
 	{
-		KviTrayIcon * w = new KviTrayIcon(c->window()->frame());
+		KviTrayIconWidget * w = new KviTrayIconWidget();
 		w->show();
 	}
 	return true;
@@ -577,24 +612,25 @@ static bool trayicon_kvs_cmd_show(KviKvsModuleCommandCall * c)
 	@title:
 		trayicon.hide
 	@short:
-		Hides the dock widget for the current frame window
+		Hides the tray icon for the current frame window
 	@syntax:
 		trayicon.hide
 	@description:
-		Hides the dock widget for the current frame window
+		Hides the  tray icon for the current frame window
 	@seealso:
 		[cmd]trayicon.show[/cmd]
 */
 
-static bool trayicon_kvs_cmd_hide(KviKvsModuleCommandCall * c)
+static bool trayicon_kvs_cmd_hide(KviKvsModuleCommandCall *)
 {
-	KviTrayIcon * w= trayicon_find(c->window()->frame());
-	if(w)delete w;
+	if(g_pTrayIcon)
+		delete g_pTrayIcon;
+	g_pTrayIcon=0;
+
 	// show the parent frame.. otherwise there will be no way to get it back
-	if(!c->window()->frame()->isVisible())
-	{
-		c->window()->frame()->show();
-	}
+	if(!g_pMainWindow->isVisible())
+		g_pMainWindow->show();
+
 	return true;
 }
 
@@ -614,13 +650,11 @@ static bool trayicon_kvs_cmd_hide(KviKvsModuleCommandCall * c)
 		[cmd]trayicon.show[/cmd], [cmd]trayicon.hide[/cmd]
 */
 
-static bool trayicon_kvs_cmd_hidewindow(KviKvsModuleCommandCall * c)
+static bool trayicon_kvs_cmd_hidewindow(KviKvsModuleCommandCall *)
 {
-	KviTrayIcon * w= trayicon_find(c->window()->frame());
-	if(w)
-	{
-		c->window()->frame()->hide();
-	}
+	if(g_pMainWindow)
+		g_pMainWindow->hide();
+
 	return true;
 }
 
@@ -635,14 +669,14 @@ static bool trayicon_kvs_cmd_hidewindow(KviKvsModuleCommandCall * c)
 	@syntax:
 		$reguser.isVisible()
 	@description:
-		Returns 1 if the dock widget is actually visible , 0 otherwise.
+		Returns 1 if the dock widget is actually visible, 0 otherwise.
 	@seealso:
 		[cmd]trayicon.show[/cmd]
 */
 
 static bool trayicon_kvs_fnc_isvisible(KviKvsModuleFunctionCall * c)
 {
-	c->returnValue()->setBoolean(trayicon_find(c->window()->frame()));
+	c->returnValue()->setBoolean(g_pTrayIcon!=0);
 	return true;
 }
 
@@ -673,10 +707,6 @@ static bool trayicon_module_init(KviModule * m)
 #endif
 	g_pDock3 = new QPixmap(buffer);
 
-	g_pTrayIconList = new KviPointerList<KviTrayIcon>;
-	g_pTrayIconList->setAutoDelete(false);
-
-
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"hide",trayicon_kvs_cmd_hide);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"hidewindow",trayicon_kvs_cmd_hidewindow);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"show",trayicon_kvs_cmd_show);
@@ -687,9 +717,8 @@ static bool trayicon_module_init(KviModule * m)
 
 static bool trayicon_module_cleanup(KviModule *)
 {
-	while(g_pTrayIconList->first())delete g_pTrayIconList->first();
-	delete g_pTrayIconList;
-	g_pTrayIconList = 0;
+	delete g_pTrayIcon;
+	g_pTrayIcon = 0;
 
 	delete g_pDock1;
 	g_pDock1 = 0;
@@ -705,7 +734,7 @@ static bool trayicon_module_cleanup(KviModule *)
 
 static bool trayicon_module_can_unload(KviModule *)
 {
-	return g_pTrayIconList->isEmpty();
+	return g_pTrayIcon==0;
 }
 
 // =======================================
@@ -718,7 +747,7 @@ KVIRC_MODULE(
 	"Copyright (C) 2007 Alexey Uzhva <alexey at kvirc dot ru>" \
 	"Copyright (C) 2008 Elvio Basello <hellvis69 at netsons dot org>",
 	"Exports the /trayicon.* interface\n",
-	trayicon_module_init ,
+	trayicon_module_init,
 	trayicon_module_can_unload,
 	0,
 	trayicon_module_cleanup,
