@@ -24,20 +24,21 @@
 
 #include "libkviurl.h"
 
-#include "kvi_module.h"
-#include "kvi_app.h"
-#include "kvi_frame.h"
-#include "kvi_menubar.h"
-#include "kvi_internalcmd.h"
-#include "kvi_iconmanager.h"
-#include "kvi_action.h"
-#include "kvi_actionmanager.h"
-#include "kvi_windowlist.h"
-#include "kvi_pointerlist.h"
-#include "kvi_kvs_eventmanager.h"
-#include "kvi_tal_popupmenu.h"
-#include "kvi_window.h"
-#include "kvi_options.h"
+#include "KviModule.h"
+#include "KviApplication.h"
+#include "KviMainWindow.h"
+#include "KviMenuBar.h"
+#include "KviMdiManager.h"
+#include "KviInternalCommand.h"
+#include "KviIconManager.h"
+#include "KviAction.h"
+#include "KviActionManager.h"
+#include "KviWindowListBase.h"
+#include "KviPointerList.h"
+#include "KviKvsEventManager.h"
+#include "KviWindow.h"
+#include "KviOptions.h"
+#include "KviQString.h"
 #include "kvi_out.h"
 
 #include <QFileDialog>
@@ -48,8 +49,8 @@
 #include <QTextStream>
 #include <QMouseEvent>
 #include <QPainter>
+#include <QMenu>
 
-static KviUrlAction * g_pUrlAction = 0;
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	extern KVIRC_API QPixmap * g_pShadedChildGlobalDesktopBackground;
@@ -76,24 +77,17 @@ void loadUrlList();
 void saveBanList();
 void loadBanList();
 UrlDlgList * findFrame();
-bool urllist();
 void url_module_help();
 
 
 #define KVI_URL_EXTENSION_NAME "URL module extenstion"
 
-static KviModuleExtension * url_extension_alloc(KviModuleExtensionAllocStruct *)
-{
-	urllist();
-	return 0;
-}
-
-KviUrlDialogTreeWidget::KviUrlDialogTreeWidget(QWidget * par)
+UrlDialogTreeWidget::UrlDialogTreeWidget(QWidget * par)
 : QTreeWidget(par)
 {
 }
 
-void KviUrlDialogTreeWidget::mousePressEvent (QMouseEvent *e)
+void UrlDialogTreeWidget::mousePressEvent (QMouseEvent *e)
 {
 	if (e->button() == Qt::RightButton)
 	{
@@ -104,7 +98,7 @@ void KviUrlDialogTreeWidget::mousePressEvent (QMouseEvent *e)
 	QTreeWidget::mousePressEvent(e);
 }
 
-void KviUrlDialogTreeWidget::paintEvent(QPaintEvent * event)
+void UrlDialogTreeWidget::paintEvent(QPaintEvent * event)
 {
 	QPainter *p = new QPainter(viewport());
 	QStyleOptionViewItem option = viewOptions();
@@ -121,7 +115,7 @@ void KviUrlDialogTreeWidget::paintEvent(QPaintEvent * event)
 		p->restore();
 	} else if(g_pShadedChildGlobalDesktopBackground)
 	{
-		QPoint pnt = ((KviWindow*)parent())->mdiParent() ? viewport()->mapTo(g_pFrame, rect.topLeft() + g_pFrame->mdiManager()->scrollBarsOffset()) : viewport()->mapTo((KviWindow*)parent(), rect.topLeft());
+		QPoint pnt = ((KviWindow*)parent())->mdiParent() ? viewport()->mapTo(g_pMainWindow, rect.topLeft() + g_pMainWindow->mdiManager()->scrollBarsOffset()) : viewport()->mapTo((KviWindow*)parent(), rect.topLeft());
 		p->drawTiledPixmap(rect,*(g_pShadedChildGlobalDesktopBackground), pnt);
 	} else {
 #endif
@@ -137,50 +131,32 @@ void KviUrlDialogTreeWidget::paintEvent(QPaintEvent * event)
 	QTreeWidget::paintEvent(event);
 }
 
-KviUrlAction::KviUrlAction(QObject * pParent)
-: KviKvsAction(
-		pParent,
-		"url.list",
-		"url.list",
-		__tr2qs("Show URL List"),
-		__tr2qs("Shows the URL list window"),
-		KviActionManager::categoryGeneric(),
-		"kvi_bigicon_www.png",
-		QString("%1").arg(KVI_SMALLICON_URL)
-	)
-{
-}
-
-KviUrlAction::~KviUrlAction()
-{
-}
-
 // ---------------------------- CLASS URLDIALOG ------------------------begin //
 
 UrlDialog::UrlDialog(KviPointerList<KviUrl> *)
-	:KviWindow(KVI_WINDOW_TYPE_TOOL,g_pFrame,"URL List")
+	:KviWindow(KviWindow::Tool,"URL List")
 {
 	setAutoFillBackground(false);
 	
-	m_pUrlList = new KviUrlDialogTreeWidget(this);
+	m_pUrlList = new UrlDialogTreeWidget(this);
 
 	m_pMenuBar = new KviTalMenuBar(this,"url menu");
 	//m_pUrlList = new KviListView(this,"list");
-	KviConfig cfg(szConfigPath,KviConfig::Read);
+	KviConfigurationFile cfg(szConfigPath,KviConfigurationFile::Read);
 /*
-	KviTalPopupMenu *pop;
+    QMenu *pop;
 
-	pop = new KviTalPopupMenu(this);
-	pop->insertItem(__tr2qs("&Configure"),this,SLOT(config()));
-// 	pop->insertItem(__tr2qs("&Help"),this,SLOT(help()));
-	pop->insertItem(__tr2qs("Clo&se"),this,SLOT(close_slot()));
+    pop = new QMenu(this);
+	pop->addAction(__tr2qs("&Configure"),this,SLOT(config()));
+// 	pop->addAction(__tr2qs("&Help"),this,SLOT(help()));
+	pop->addAction(__tr2qs("Clo&se"),this,SLOT(close_slot()));
 	pop->setTitle(__tr2qs("&Module"));
 	m_pMenuBar->addMenu(pop);
 
-	pop = new KviTalPopupMenu(this);
-	pop->insertItem(__tr2qs("&Load"),this,SLOT(loadList()));
-	pop->insertItem(__tr2qs("&Save"),this,SLOT(saveList()));
-	pop->insertItem(__tr2qs("&Clear"),this,SLOT(clear()));
+    pop = new QMenu(this);
+	pop->addAction(__tr2qs("&Load"),this,SLOT(loadList()));
+	pop->addAction(__tr2qs("&Save"),this,SLOT(saveList()));
+	pop->addAction(__tr2qs("&Clear"),this,SLOT(clear()));
 	pop->setTitle(__tr2qs("&List"));
 	m_pMenuBar->addMenu(pop);
 */
@@ -287,9 +263,9 @@ void UrlDialog::findtext()
 	}
 	for(KviUrl *tmp=g_pList->first();tmp;tmp=g_pList->next())
 	{
-		if (tmp->url == KviStr(m_pUrlList->currentItem()->text(0))) {
+		if (tmp->url == KviCString(m_pUrlList->currentItem()->text(0))) {
 			g_pList->find(tmp);
-			KviStr ft="findtext %";
+			KviCString ft="findtext %";
 			ft.replaceAll('%',tmp->url.ptr());
 			KviWindow *wnd = m_pFrm->findWindow(tmp->window.ptr());
 			if (wnd) {
@@ -306,54 +282,62 @@ void UrlDialog::findtext()
 void UrlDialog::dblclk_url(QTreeWidgetItem *item, int)
 {
 	QString cmd="openurl ";
-	cmd.append(item->text(0));
+	QString szUrl = item->text(0);
+	KviQString::escapeKvs(&szUrl);
+	cmd.append(szUrl);
 	KviKvsScript::run(cmd,this);
 }
 
 void UrlDialog::popup(QTreeWidgetItem *item, const QPoint &point)
 {
 	m_szUrl = item->text(0);
-	KviTalPopupMenu p(0,"menu");
-	p.insertItem(__tr2qs("&Remove"),this,SLOT(remove()));
-// 	p.insertItem(__tr2qs("&Find Text"),this,SLOT(findtext()));
-	p.insertSeparator();
-	m_pListPopup = new KviTalPopupMenu(0,"list");
+    QMenu p("menu", 0);
+	p.addAction(__tr2qs("&Remove"),this,SLOT(remove()));
+// 	p.addAction(__tr2qs("&Find Text"),this,SLOT(findtext()));
+    p.addSeparator();
+    m_pListPopup = new QMenu("list", 0);
 
-	for(KviWindow *w=g_pFrame->windowList()->first();w;w=g_pFrame->windowList()->next())
+	for(KviWindow *w=g_pMainWindow->windowList()->first();w;w=g_pMainWindow->windowList()->next())
 	{
-		if ((w->type() == KVI_WINDOW_TYPE_CHANNEL) ||
-			(w->type() == KVI_WINDOW_TYPE_QUERY) ||
-			 (w->type() == KVI_WINDOW_TYPE_DCCCHAT))
+		if ((w->type() == KviWindow::Channel) ||
+			(w->type() == KviWindow::Query) ||
+			 (w->type() == KviWindow::DccChat))
 		{
 			m_pListPopup->addAction(w->plainTextCaption());
 		}
 	}
-	p.insertItem(__tr2qs("&Say to Window"),m_pListPopup);
+    p.addAction(__tr2qs("&Say to Window"))->setMenu(m_pListPopup);
 	connect(m_pListPopup,SIGNAL(triggered(QAction *)), this, SLOT(sayToWin(QAction *)));
 	p.exec(point);
 }
 
 void UrlDialog::contextMenu(const QPoint &point)
 {
-	KviTalPopupMenu p(0,"contextmenu");
-	p.insertItem(__tr2qs("Configure"),this,SLOT(config()));
+    QMenu p("contextmenu", 0);
+	p.addAction(__tr2qs("Configure"),this,SLOT(config()));
 	p.exec(point);
 }
 
 void UrlDialog::sayToWin(QAction * act)
 {
 	KviWindow *wnd = g_pApp->findWindowByCaption(act->text());
-	QString say=QString("PRIVMSG %1 %2").arg(wnd->windowName(), m_szUrl);
 	if(wnd)
 	{
+		QString szUrl = m_szUrl;
+		QString szWindow = wnd->windowName();
+		KviQString::escapeKvs(&szUrl);
+		KviQString::escapeKvs(&szWindow);
+		QString say=QString("PRIVMSG %1 %2").arg(szWindow, szUrl);
 		KviKvsScript::run(say,wnd);
-		g_pFrame->setActiveWindow(wnd);
-	} else QMessageBox::warning(0,__tr2qs("Warning - KVIrc"),__tr2qs("Window not found."),QMessageBox::Ok,QMessageBox::NoButton,QMessageBox::NoButton);
+		g_pMainWindow->setActiveWindow(wnd);
+	} else {
+		QMessageBox::warning(0,__tr2qs("Warning - KVIrc"),__tr2qs("Window not found."),QMessageBox::Ok,QMessageBox::NoButton,QMessageBox::NoButton);
+	}
 }
 
 QPixmap *UrlDialog::myIconPtr()
 {
-	return g_pIconManager->getSmallIcon(KVI_SMALLICON_URL);
+	return g_pIconManager->getSmallIcon(KviIconManager::Url);
 }
 
 void UrlDialog::addUrl(QString url, QString window, QString count, QString timestamp)
@@ -386,7 +370,7 @@ void UrlDialog::resizeEvent(QResizeEvent *)
 UrlDialog::~UrlDialog()
 {
 	/*
-	KviConfig cfg(szConfigPath,KviConfig::Write);
+	KviConfigurationFile cfg(szConfigPath,KviConfigurationFile::Write);
 	cfg.setGroup("ConfigDialog");
 	if (cfg.readBoolEntry("SaveColumnWidthOnClose",false)) {
 		cfg.setGroup("ColsWidth");
@@ -416,7 +400,7 @@ ConfigDialog::ConfigDialog()
 
 	QGridLayout *g = new QGridLayout(this);
 
-	KviConfig *cfg = new KviConfig(szConfigPath,KviConfig::Read);
+	KviConfigurationFile *cfg = new KviConfigurationFile(szConfigPath,KviConfigurationFile::Read);
 	cfg->setGroup("ConfigDialog");
 
 	cb[0] = new QCheckBox(__tr2qs("Save URL list on module unload"),this);
@@ -457,7 +441,7 @@ void ConfigDialog::discardbtn()
 
 void ConfigDialog::acceptbtn()
 {
-	KviConfig *cfg = new KviConfig(szConfigPath,KviConfig::Write);
+	KviConfigurationFile *cfg = new KviConfigurationFile(szConfigPath,KviConfigurationFile::Write);
 	cfg->setGroup("ConfigDialog");
 
 	if (m_pBanFrame) m_pBanFrame->saveBans(cfg);
@@ -561,7 +545,7 @@ void BanFrame::removeBan()
 
 }
 
-void BanFrame::saveBans(KviConfig *cfg)
+void BanFrame::saveBans(KviConfigurationFile *cfg)
 {
 	cfg->writeEntry("BanEnabled",m_pEnable->isChecked());
 	if (m_pEnable->isChecked()) saveBanList();
@@ -577,7 +561,7 @@ BanFrame::~BanFrame()
 void saveUrlList()
 {
 	QString urllist;
-	g_pApp->getLocalKvircDirectory(urllist,KviApp::ConfigPlugins);
+	g_pApp->getLocalKvircDirectory(urllist,KviApplication::ConfigPlugins);
 	urllist += g_pUrlListFilename;
 	QFile file;
 	file.setFileName(urllist);
@@ -601,7 +585,7 @@ void saveUrlList()
 void loadUrlList()
 {
 	QString urllist;
-	g_pApp->getLocalKvircDirectory(urllist,KviApp::ConfigPlugins);
+	g_pApp->getLocalKvircDirectory(urllist,KviApplication::ConfigPlugins);
 	urllist += g_pUrlListFilename;
 	QFile file;
 	file.setFileName(urllist);
@@ -641,7 +625,7 @@ void loadUrlList()
 void saveBanList()
 {
 	QString banlist;
-	g_pApp->getLocalKvircDirectory(banlist,KviApp::ConfigPlugins);
+	g_pApp->getLocalKvircDirectory(banlist,KviApplication::ConfigPlugins);
 	banlist += g_pBanListFilename;
 	QFile file;
 	file.setFileName(banlist);
@@ -661,7 +645,7 @@ void saveBanList()
 void loadBanList()
 {
 	QString banlist;
-	g_pApp->getLocalKvircDirectory(banlist,KviApp::ConfigPlugins);
+	g_pApp->getLocalKvircDirectory(banlist,KviApplication::ConfigPlugins);
 	banlist += g_pBanListFilename;
 	QFile file;
 	file.setFileName(banlist);
@@ -709,7 +693,18 @@ void loadBanList()
 
 static bool url_kvs_cmd_list(KviKvsModuleCommandCall *)
 {
-	urllist();
+	UrlDlgList *tmpitem = findFrame();
+	if (tmpitem->dlg) return false;
+
+	tmpitem->dlg = new UrlDialog(g_pList);
+	g_pMainWindow->addWindow(tmpitem->dlg);
+
+	for(KviUrl *tmp=g_pList->first();tmp;tmp=g_pList->next())
+	{
+		QString tmpCount;
+		tmpCount.setNum(tmp->count);
+		tmpitem->dlg->addUrl(QString(tmp->url), QString(tmp->window), tmpCount, QString(tmp->timestamp));
+	}
 	return true;
 }
 
@@ -726,24 +721,6 @@ UrlDlgList *findFrame()
 	return tmpitem;
 }
 
-bool urllist()
-{
-	UrlDlgList *tmpitem = findFrame();
-	if (tmpitem->dlg) return false;
-
-	tmpitem->dlg = new UrlDialog(g_pList);
-	g_pFrame->addWindow(tmpitem->dlg);
-
-	for(KviUrl *tmp=g_pList->first();tmp;tmp=g_pList->next())
-	{
-		QString tmpCount;
-		tmpCount.setNum(tmp->count);
-		tmpitem->dlg->addUrl(QString(tmp->url), QString(tmp->window), tmpCount, QString(tmp->timestamp));
-	}
-	return true;
-}
-
-
 /*
  	@doc: url.config
 	@type:
@@ -862,12 +839,6 @@ bool urllist_module_event_onUrl(KviKvsModuleEventCall * c)
 
 static bool url_module_init(KviModule *m)
 {
-	KviModuleExtensionDescriptor * d = m->registerExtension("tool",
-							KVI_URL_EXTENSION_NAME,
-							__tr2qs("View URL list"),
-							url_extension_alloc);
-	if(d)d->setIcon(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_URL)));
-
 	g_pList = new KviPointerList<KviUrl>;
 	g_pList->setAutoDelete(true);
 
@@ -879,12 +850,10 @@ static bool url_module_init(KviModule *m)
 
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"list",url_kvs_cmd_list);
 	KVSM_REGISTER_SIMPLE_COMMAND(m,"config",url_kvs_cmd_config);
-	g_pUrlAction = new KviUrlAction(KviActionManager::instance());
-	KviActionManager::instance()->registerAction(g_pUrlAction);
 
 	m->kvsRegisterAppEventHandler(KviEvent_OnURL,urllist_module_event_onUrl);
 
-	g_pApp->getLocalKvircDirectory(szConfigPath,KviApp::ConfigPlugins,"url.conf");
+	g_pApp->getLocalKvircDirectory(szConfigPath,KviApplication::ConfigPlugins,"url.conf");
 
 	loadUrlList();
 	loadBanList();
@@ -898,7 +867,7 @@ static bool url_module_init(KviModule *m)
 
 static bool url_module_cleanup(KviModule *)
 {
-	KviConfig cfg(szConfigPath,KviConfig::Read);
+	KviConfigurationFile cfg(szConfigPath,KviConfigurationFile::Read);
 	cfg.setGroup("ConfigDialog");
 	if (cfg.readBoolEntry("SaveUrlListOnUnload",false) == true) saveUrlList();
 	for (UrlDlgList *tmpitem=g_pUrlDlgList->first();tmpitem;tmpitem=g_pUrlDlgList->next()) {
@@ -912,8 +881,6 @@ static bool url_module_cleanup(KviModule *)
 
 	delete g_pUrlDlgList;
 	g_pUrlDlgList = 0;
-	delete g_pUrlAction;
-	g_pUrlAction = 0;
 
 	return true;
 }
@@ -962,7 +929,7 @@ void url_module_config()
 
 KVIRC_MODULE(
 	"URL",
-	"4.0.0" ,
+	"4.0.0",
 	"Copyright (C) 2002 Andrea Parrella <yap@yapsoft.it>",
 	"url list module for KVIrc",
 	url_module_init,
